<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru">
<context>
    <name>AboutDialog</name>
    <message>
        <source>about_dialog_title</source>
        <translation type="obsolete">О программе</translation>
    </message>
    <message>
        <source>web_page</source>
        <translation type="obsolete">Домашняя страница</translation>
    </message>
    <message>
        <source>close</source>
        <translation type="obsolete">Закрыть</translation>
    </message>
    <message>
        <location filename="../src/main_window/ui/AboutDialog.ui" line="23"/>
        <source>About UGENE</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../src/main_window/ui/AboutDialog.ui" line="60"/>
        <source>Web Page</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/main_window/ui/AboutDialog.ui" line="80"/>
        <source>Close</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>AppContextImpl</name>
    <message>
        <location filename="../src/Main.cpp" line="253"/>
        <source>UGENE initialization started</source>
        <translation type="unfinished">Инициализация UGENE</translation>
    </message>
    <message>
        <location filename="../src/Main.cpp" line="273"/>
        <source>Style not available %1</source>
        <translation type="unfinished">Стиль не доступен: %1</translation>
    </message>
    <message>
        <location filename="../src/Main.cpp" line="440"/>
        <source>UGENE started</source>
        <translation type="unfinished">UGENE готов к работе</translation>
    </message>
</context>
<context>
    <name>AppSettingsDialog</name>
    <message>
        <location filename="../src/app_settings/ui/AppSettingsDialog.ui" line="13"/>
        <source>AppSettingsDialog</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/app_settings/ui/AppSettingsDialog.ui" line="49"/>
        <source>1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/app_settings/ui/AppSettingsDialog.ui" line="81"/>
        <source>ok</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../src/app_settings/ui/AppSettingsDialog.ui" line="88"/>
        <source>cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>CreateNewProjectDialog</name>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="20"/>
        <source>Dialog</source>
        <translation>Содать проект</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="47"/>
        <source>project_name_label</source>
        <translation>Имя проекта:</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="57"/>
        <source>project_folder_label</source>
        <translation>Папка проекта:</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="64"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="71"/>
        <source>project_file_label</source>
        <translation>Файл проекта</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="104"/>
        <source>create_button_label</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/CreateNewProjectWidget.ui" line="114"/>
        <source>cancel_button_label</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>ExportProjectDialog</name>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="14"/>
        <source>Export Project</source>
        <translation>Экспортировать проект</translation>
    </message>
    <message>
        <source>Destination directory</source>
        <translation type="obsolete">Выбор директории</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation type="obsolete">...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="25"/>
        <source>Destination folder</source>
        <translation>Сохранить в директорию:</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="42"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="49"/>
        <source>Project file name</source>
        <translation>Имя файла проекта:</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="96"/>
        <source>OK</source>
        <translation>Готово</translation>
    </message>
    <message>
        <location filename="../src/project_support/ui/ExportProjectDialog.ui" line="103"/>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
</context>
<context>
    <name>LogSettingsWidget</name>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="14"/>
        <source>LogSettingsWidget</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="47"/>
        <source>Log format</source>
        <translation>Формат записей</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="53"/>
        <source>Show date</source>
        <translation>Показывать дату</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="60"/>
        <source>Show log level</source>
        <translation>Показывать тип</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/ui/LogSettingsWidget.ui" line="67"/>
        <source>Show log category</source>
        <translation>Показывать категорию</translation>
    </message>
    <message>
        <source>category_name</source>
        <translation type="obsolete">Категория</translation>
    </message>
    <message>
        <source>trace_level</source>
        <translation type="obsolete">Трассировка</translation>
    </message>
    <message>
        <source>details_level</source>
        <translation type="obsolete">Детали</translation>
    </message>
    <message>
        <source>info_level</source>
        <translation type="obsolete">Информация</translation>
    </message>
    <message>
        <source>error_level</source>
        <translation type="obsolete">Ошибки</translation>
    </message>
    <message>
        <source>message_format_group</source>
        <translation type="obsolete">Формат записей</translation>
    </message>
    <message>
        <source>show_date</source>
        <translation type="obsolete">Показывать дату</translation>
    </message>
    <message>
        <source>show_level</source>
        <translation type="obsolete">Показывать тип</translation>
    </message>
    <message>
        <source>show_category</source>
        <translation type="obsolete">Показывать категорию</translation>
    </message>
</context>
<context>
    <name>NetworkSettingsWidget</name>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="20"/>
        <source>network_settings_title</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="32"/>
        <source>proxy_group_label</source>
        <translation>Прокси</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="40"/>
        <source>type_label</source>
        <translation>Тип:</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="47"/>
        <source>server_label</source>
        <translation>Сервер:</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="54"/>
        <source>port_l</source>
        <translation>Порт:</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="67"/>
        <source>http_l</source>
        <translation>HTTP</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="105"/>
        <source>Use authentication with HTTP proxy:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="117"/>
        <source>Login</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="127"/>
        <source>Password</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="189"/>
        <source>exceptions_check_label</source>
        <translation>Не использовать прокси для следующих адресов (разделять переводом строки):</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="205"/>
        <source>SSL settings</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/ui/NetworkSettingsWidget.ui" line="213"/>
        <source>Secure Socket protocol:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>PluginViewWidget</name>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="13"/>
        <source>Plugin Viewer</source>
        <translation>Управление модулями</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="41"/>
        <source>item_type_label</source>
        <translation>Тип</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="46"/>
        <source>item_name_label</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="51"/>
        <source>item_state_label</source>
        <translation>Статус</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/ui/PluginViewerWidget.ui" line="56"/>
        <source>item_desc_label</source>
        <translation>Описание</translation>
    </message>
</context>
<context>
    <name>ProjectViewWidget</name>
    <message>
        <location filename="../src/project_view/ui/ProjectViewWidget.ui" line="13"/>
        <source>Form</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/project_view/ui/ProjectViewWidget.ui" line="55"/>
        <source>Name filter</source>
        <translation>Фильтр</translation>
    </message>
    <message>
        <location filename="../src/project_view/ui/ProjectViewWidget.ui" line="118"/>
        <source>Bookmarks</source>
        <translation>Закладки</translation>
    </message>
    <message>
        <location filename="../src/project_view/ui/ProjectViewWidget.ui" line="83"/>
        <source>Objects</source>
        <translation>Объекты</translation>
    </message>
</context>
<context>
    <name>ResourceSettingsWidget</name>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="13"/>
        <source>Resource settings</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="19"/>
        <source>Application resources</source>
        <translation>Общие ресурсы приложения</translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="31"/>
        <source>Optimize for CPU count</source>
        <translation>Оптимизировать под кол-во ЦПУ</translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="63"/>
        <source>Tasks memory limit</source>
        <translation>Ограничение по памяти для задач</translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="82"/>
        <source>Mb</source>
        <translation>Мб</translation>
    </message>
    <message>
        <location filename="../src/app_settings/resource_settings/ui/ResourceSettingsWidget.ui" line="104"/>
        <source>Threads limit</source>
        <translation>Ограничение по параллельным потокам</translation>
    </message>
</context>
<context>
    <name>ScriptLibraryEditor</name>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="20"/>
        <source>Folders to search scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="30"/>
        <source>Add folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="37"/>
        <source>Remove folder</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="57"/>
        <source>Available scripts</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="67"/>
        <source>Refresh</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="74"/>
        <source>Edit</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="94"/>
        <source>Script preview</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/script/ui/ScriptLibraryEditor.ui" line="108"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>ScriptManagerWidget</name>
    <message>
        <source>script_manager</source>
        <translation type="obsolete">Менеджер скриптов</translation>
    </message>
    <message>
        <source>add_b</source>
        <translation type="obsolete">Добавить</translation>
    </message>
    <message>
        <source>reload_b</source>
        <translation type="obsolete">Обновить</translation>
    </message>
    <message>
        <source>del_b</source>
        <translation type="obsolete">Удалить</translation>
    </message>
    <message>
        <source>script_name</source>
        <translation type="obsolete">Имя</translation>
    </message>
    <message>
        <source>script_type</source>
        <translation type="obsolete">Тип</translation>
    </message>
    <message>
        <source>script_url</source>
        <translation type="obsolete">Файл</translation>
    </message>
    <message>
        <source>script_status</source>
        <translation type="obsolete">Статус</translation>
    </message>
    <message>
        <source>close_b</source>
        <translation type="obsolete">Закрыть</translation>
    </message>
</context>
<context>
    <name>U2::AboutDialogController</name>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="51"/>
        <source>Max score: %1</source>
        <translation>Рекорд: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="95"/>
        <source>Score: %1</source>
        <translation>Счёт: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="99"/>
        <source>Level: %1</source>
        <translation>Скорость: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="105"/>
        <source>About UGENE</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="107"/>
        <source>Have fun ;-)</source>
        <translation>Расслабимся? ;-)</translation>
    </message>
</context>
<context>
    <name>U2::AppContextImpl</name>
    <message>
        <source>UGENE initialization started</source>
        <translation type="obsolete">Инициализация UGENE</translation>
    </message>
    <message>
        <source>Style not available %1</source>
        <translation type="obsolete">Стиль не доступен: %1</translation>
    </message>
    <message>
        <source>UGENE started</source>
        <translation type="obsolete">UGENE готов к работе</translation>
    </message>
</context>
<context>
    <name>U2::AppSettingsDialogController</name>
    <message>
        <location filename="../src/app_settings/AppSettingsDialogController.cpp" line="49"/>
        <source>default_err</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/app_settings/AppSettingsDialogController.cpp" line="51"/>
        <source>error</source>
        <translation>Ошибка</translation>
    </message>
</context>
<context>
    <name>U2::AppSettingsGUIImpl</name>
    <message>
        <location filename="../src/app_settings/AppSettingsGUIImpl.cpp" line="19"/>
        <source>Preferences...</source>
        <translation>Установки...</translation>
    </message>
</context>
<context>
    <name>U2::CheckUpdatesTask</name>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="17"/>
        <source>Check for updates</source>
        <translation>Проверить обновления</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="26"/>
        <source>Connecting to updates server</source>
        <translation>Соединение с сервером</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="38"/>
        <source>Connection error: %1</source>
        <translation>Ошибка соединения: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="49"/>
        <source>Your version:</source>
        <translation>Локальная версия:</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="50"/>
        <source>Latest version:</source>
        <translation>Последняя версия:</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="53"/>
        <source>You have the latest  version</source>
        <translation>У вас установлена самая последняя версия</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="57"/>
        <source>Version information</source>
        <translation>Информация</translation>
    </message>
    <message>
        <location filename="../src/main_window/CheckUpdatesTask.cpp" line="62"/>
        <source>Visit web site</source>
        <translation>Перейти на сайт UGENE</translation>
    </message>
</context>
<context>
    <name>U2::CloseProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="46"/>
        <source>close_project_task_name</source>
        <translation>Закрытие проекта</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="52"/>
        <source>error_no_active_project</source>
        <translation>Нет проектов</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="70"/>
        <source>Save and close project</source>
        <translation>Сохранить и закрыть проект</translation>
    </message>
</context>
<context>
    <name>U2::DisablePluginViewerTask</name>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerImpl.cpp" line="35"/>
        <source>disable_plugin_viewer_task</source>
        <translation>Закрытие списка модулей</translation>
    </message>
</context>
<context>
    <name>U2::DisableProjectViewTask</name>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="814"/>
        <source>disable_project_view</source>
        <translation>Остановка сервиса просмотра проектов</translation>
    </message>
</context>
<context>
    <name>U2::EnablePluginViewerTask</name>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerImpl.cpp" line="23"/>
        <source>enable_plugin_viewer_task</source>
        <translation>Загрузка списка модулей</translation>
    </message>
</context>
<context>
    <name>U2::EnableProjectViewTask</name>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="802"/>
        <source>enable_project_view</source>
        <translation>Запуск сервиса просмотра проектов</translation>
    </message>
</context>
<context>
    <name>U2::ExportProjectDialogController</name>
    <message>
        <source>Entered save directory path is empty</source>
        <translation type="obsolete">Указанный путь для экспорта пуст</translation>
    </message>
    <message>
        <source>Directory to save is not exists</source>
        <translation type="obsolete">Директория для экспорта не существует</translation>
    </message>
    <message>
        <location filename="../src/project_support/ExportProjectDialogController.cpp" line="48"/>
        <source>Choose Directory</source>
        <translation>Выбор директории</translation>
    </message>
</context>
<context>
    <name>U2::ExportProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="420"/>
        <source>Export project task</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="432"/>
        <source>One of the documents has empty URL</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::GTest_ExportProject</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="555"/>
        <source>GTest_ExportProject::prepare unable to clean directory for exporting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="560"/>
        <source>GTest_ExportProject::prepare unable to create directory for exporting</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="580"/>
        <source>GTest_ExportProject::cleanup unable to delete exported files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::GTest_LoadDocumentFromProject</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="641"/>
        <source>No project loaded</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="645"/>
        <source>Document name to load is empty</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="660"/>
        <source>File %1 not found in project</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::GTest_LoadProject</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="502"/>
        <source>Unload previous project, then load new</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::LoadProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="361"/>
        <source>load_project_task_name</source>
        <translation>Открытие проекта</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="381"/>
        <source>Unable to detect parser for project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>error_open_file %1</source>
        <translation type="obsolete">Ошибка открытия файла проекта: %1</translation>
    </message>
    <message>
        <source>error_invalid_content %1</source>
        <translation type="obsolete">Некорректный формат проекта: %1</translation>
    </message>
    <message>
        <source>last_loaded_state_was_locked_by_format</source>
        <translation type="obsolete">Блокировка с последней загрузки</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="372"/>
        <source>Loading project from: %1</source>
        <translation>Читается файл проекта: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="386"/>
        <source>Project loaded: %1</source>
        <translation>Проект загружен: %1</translation>
    </message>
</context>
<context>
    <name>U2::LogSettingsPageController</name>
    <message>
        <source>Log Settings</source>
        <translation type="obsolete">Настройки журнала</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/LogSettingsGUIController.cpp" line="17"/>
        <source>Logging</source>
        <translation>Настройки логирования</translation>
    </message>
</context>
<context>
    <name>U2::LogSettingsPageWidget</name>
    <message>
        <location filename="../src/app_settings/logview_settings/LogSettingsGUIController.cpp" line="57"/>
        <source>Category</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/LogSettingsGUIController.cpp" line="64"/>
        <source>&lt;&lt;all&gt;&gt;</source>
        <translation>&lt;&lt; все &gt;&gt;</translation>
    </message>
    <message>
        <location filename="../src/app_settings/logview_settings/LogSettingsGUIController.cpp" line="217"/>
        <source>Sample text</source>
        <translation>образец</translation>
    </message>
</context>
<context>
    <name>U2::LogViewDockWidget</name>
    <message>
        <source>Log</source>
        <translation type="obsolete">Журнал</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation type="obsolete">Настройки журнала</translation>
    </message>
    <message>
        <source>logview_copy</source>
        <translation type="obsolete">Скопировать в буфер</translation>
    </message>
    <message>
        <source>Dump performance counters</source>
        <translation type="obsolete">Вывести показания спидометров</translation>
    </message>
    <message>
        <source>Append separator</source>
        <translation type="obsolete">Добавить разделитель</translation>
    </message>
    <message>
        <source>Clear log</source>
        <translation type="obsolete">Очистить журнал</translation>
    </message>
    <message>
        <source>logview_set_case</source>
        <translation type="obsolete">Учитывать Регистр</translation>
    </message>
    <message>
        <source>logview_use_regexp</source>
        <translation type="obsolete">Использовать регулярные выражения</translation>
    </message>
</context>
<context>
    <name>U2::MWMDIManagerImpl</name>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="41"/>
        <source>close_active_view</source>
        <translation>Закрыть активное окно</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="43"/>
        <source>close_active_view_statustip</source>
        <translation>Закрыть активное окно</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="46"/>
        <source>close_all_mdi_windows</source>
        <translation>Закрыть все</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="47"/>
        <source>close_all_mdi_windows_statustip</source>
        <translation>Закрыть все окна</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="50"/>
        <source>tile_mdi_windows</source>
        <translation>Уложить черепицей</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="51"/>
        <source>tile_mdi_windows_statustip</source>
        <translation>Расположить окна черепицей (мозаично)</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="54"/>
        <source>cascade_mdi_windows</source>
        <translation>Уложить каскадом</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="55"/>
        <source>cascade_mdi_windows_statustip</source>
        <translation>Расположить окна каскадом</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="58"/>
        <source>next_mdi_window</source>
        <translation>Следующее окно</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="59"/>
        <source>next_mdi_window_statustip</source>
        <translation>Перейти к следующему окну</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="63"/>
        <source>previous_mdi_window</source>
        <translation>Предыдущее окно</translation>
    </message>
    <message>
        <location filename="../src/main_window/MDIManagerImpl.cpp" line="64"/>
        <source>previous_mdi_window_statustip</source>
        <translation>Перейти к предыдущему окну</translation>
    </message>
    <message>
        <source>Closing window %1</source>
        <translation type="obsolete">Закрыто окно: %1</translation>
    </message>
    <message>
        <source>Adding window: %1</source>
        <translation type="obsolete">Открыто окно: %1</translation>
    </message>
</context>
<context>
    <name>U2::MWMenuManagerImpl</name>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="10"/>
        <source>mw_menu_file</source>
        <translation>&amp;Файл</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="11"/>
        <source>mw_menu_actions</source>
        <translation>Операции</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="12"/>
        <source>mw_menu_settings</source>
        <translation>Настройки</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="13"/>
        <source>mw_menu_tools</source>
        <translation>Инструменты</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="14"/>
        <source>mw_menu_window</source>
        <translation>Окна</translation>
    </message>
    <message>
        <location filename="../src/main_window/MenuManager.cpp" line="15"/>
        <source>mw_menu_help</source>
        <translation>Помощь</translation>
    </message>
</context>
<context>
    <name>U2::MainWindowImpl</name>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="155"/>
        <source>mw_menu_file_exit</source>
        <translation>Вы&amp;ход</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="170"/>
        <source>Download user manual</source>
        <translation type="unfinished">Загрузить руководство пользователя</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="193"/>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="195"/>
        <source>main_window_title</source>
        <translation>UGENE</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="236"/>
        <source>UGENE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="237"/>
        <source>Shutdown already in process. Close UGENE immediately</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="238"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="239"/>
        <source>Wait</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="159"/>
        <source>mw_menu_help_about</source>
        <translation>О программе</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="167"/>
        <source>Check for Updates</source>
        <translation>Проверить обновления</translation>
    </message>
    <message>
        <location filename="../src/main_window/MainWindowImpl.cpp" line="164"/>
        <source>Visit UGENE&apos;s Web Site</source>
        <translation>Перейти на сайт UGENE</translation>
    </message>
</context>
<context>
    <name>U2::NetworkSettingsPageController</name>
    <message>
        <source>network_settings</source>
        <translation type="obsolete">Конфигурация сети</translation>
    </message>
    <message>
        <location filename="../src/app_settings/network_settings/NetworkSettingsGUIController.cpp" line="15"/>
        <source>Network</source>
        <translation>Сетевые настройки</translation>
    </message>
</context>
<context>
    <name>U2::OpenProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="77"/>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="82"/>
        <source>open_project_task_name</source>
        <translation>Открытие документов/проекта</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="98"/>
        <source>invalid_url%1</source>
        <translation>Некорректный файл проекта: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="105"/>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="106"/>
        <source>Project already opened</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="111"/>
        <source>UGENE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="112"/>
        <source>New project can either be opened in a new window or replace the project in the existing. How would you like to open the project?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="113"/>
        <source>New Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="114"/>
        <source>This Window</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="122"/>
        <source>Failed to open new instance of UGENE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="169"/>
        <source>unsupported_document%1</source>
        <translation>Неизвестный формат документа: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="189"/>
        <source>The document already in the project</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="198"/>
        <source>The document is already opened: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="162"/>
        <source>ignore %1</source>
        <translation>Проигнорирован открываемый документ: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="152"/>
        <source>Creating new project</source>
        <translation>Создаётся новый проект</translation>
    </message>
    <message>
        <source>Document is already opened: %1</source>
        <translation type="obsolete">Документ уже загружен: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="128"/>
        <source>Stopped loading project: %1. Reason: active project found</source>
        <translation>Загрузка проекта остановлена: %1, поскольку активен другой проект</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="184"/>
        <source>Document wasn&apos;t added to project: unsupported format</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="189"/>
        <source>warning</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::PluginViewerController</name>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="47"/>
        <source>plugin_view_window_title</source>
        <translation>Управление модулями</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="78"/>
        <source>Plugins...</source>
        <translation>Управление модулями...</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="83"/>
        <source>add_plugin_label</source>
        <translation>Добавить модуль</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="92"/>
        <source>enable_service_label</source>
        <translation>Запустить сервис</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="95"/>
        <source>disable_service_label</source>
        <translation>Остановить сервис</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="239"/>
        <source>add_plugin_caption</source>
        <translation>Загрузить внешний модуль</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="242"/>
        <source>genome_browser2_plugin_files</source>
        <translation>Внешние модули</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="387"/>
        <source>item_type_plugin_label</source>
        <translation>Модуль</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="393"/>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="412"/>
        <source>item_state_on</source>
        <translation>Запущен</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="409"/>
        <source>item_type_service_label</source>
        <translation>Сервис</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="413"/>
        <source>item_state_off</source>
        <translation>Остановлен</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="86"/>
        <source>enable_plugin_action</source>
        <translation>Включить модуль</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="89"/>
        <source>disable_plugin_action</source>
        <translation>Выключить модуль</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="260"/>
        <source>add_plugin_error_caption</source>
        <translation>Ошибка загрузки модуля</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerController.cpp" line="392"/>
        <source>removed_after_restart</source>
        <translation>К удалению</translation>
    </message>
</context>
<context>
    <name>U2::PluginViewerImpl</name>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerImpl.h" line="18"/>
        <source>plugin_viewer_sname</source>
        <translation>Управление модулями</translation>
    </message>
    <message>
        <location filename="../src/plugin_viewer/PluginViewerImpl.h" line="18"/>
        <source>plugin_viewer_sdesc</source>
        <translation>Управление подключамыми модулями и сервисами</translation>
    </message>
</context>
<context>
    <name>U2::ProjectDialogController</name>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="400"/>
        <source>Choose directory</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ProjectImpl</name>
    <message>
        <source>add_document_url_%1</source>
        <translation type="obsolete">Документ добавлен в проект: %1</translation>
    </message>
    <message>
        <source>remove_documenturl_%1</source>
        <translation type="obsolete">Документ удалён из проекта: %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectImpl.cpp" line="72"/>
        <source>Project URL is set to %1
</source>
        <translation>Адрес проекта изменён : %1</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectImpl.cpp" line="90"/>
        <source>Adding document to the project: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectImpl.cpp" line="117"/>
        <source>Not enough resources for load document, resource name: &apos;%1&apos; available: %2%3 requested: %4%3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectImpl.cpp" line="124"/>
        <source>Removing document from the project: %1</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>U2::ProjectLoaderImpl</name>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="37"/>
        <source>&amp;New project...</source>
        <translation>Создать проект...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="141"/>
        <source>UGENE project file</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="143"/>
        <source>Select files to open...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="363"/>
        <source>new_project_default_name</source>
        <translation>Новый проект</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="364"/>
        <source>new_project_default_file</source>
        <translation>проект</translation>
    </message>
    <message>
        <source>gb_project_file</source>
        <translation type="obsolete">Файлы проектов</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="43"/>
        <source>New document from text...</source>
        <translation>Создать документ...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="48"/>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="54"/>
        <source>Access remote database...</source>
        <translation type="unfinished">Доступ к удаленным базам данных...</translation>
    </message>
    <message>
        <source>open_dialog_caption</source>
        <translation type="obsolete">Открыть документ или проект</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="350"/>
        <source>Save project as</source>
        <translation>Сохранить проект как ...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="351"/>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="69"/>
        <source>Recent Projects</source>
        <translation>История проектов</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectLoaderImpl.cpp" line="73"/>
        <source>Recent Files</source>
        <translation>История файлов</translation>
    </message>
</context>
<context>
    <name>U2::ProjectServiceDisableTask</name>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="159"/>
        <source>project_disable_task</source>
        <translation>Остановка сервиса проектов</translation>
    </message>
</context>
<context>
    <name>U2::ProjectServiceEnableTask</name>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="111"/>
        <source>project_enable_task</source>
        <translation>Запуск сервиса проектов</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="120"/>
        <source>&amp;Save all</source>
        <translation>Сохранить проект</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="129"/>
        <source>&amp;Close project</source>
        <translation>Закрыть проект</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="135"/>
        <source>Export project...</source>
        <translation>Экспортировать проект...</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="126"/>
        <source>Save project &amp;as...</source>
        <translation>Сохранить проект как...</translation>
    </message>
</context>
<context>
    <name>U2::ProjectServiceImpl</name>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="26"/>
        <source>project_sname</source>
        <translation>Поддержка проектов</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectServiceImpl.cpp" line="26"/>
        <source>project_sdesc</source>
        <translation>Сервис управления проектами запускается автоматически при открытии или создании проекта и обеспечивает поддержку прочих сервисов.</translation>
    </message>
    <message>
        <source>Directory doesn&apos;t exists</source>
        <translation type="obsolete">Папка не существует</translation>
    </message>
    <message>
        <source>Directory %1 doesn&apos;t exists
Do you wish to create this directory?</source>
        <translation type="obsolete">Папка %1 не существует
Вы желаете создать эту папку?</translation>
    </message>
    <message>
        <source>Unable to create directory %1!</source>
        <translation type="obsolete">Невозможно создать папку %1!</translation>
    </message>
    <message>
        <source>Folder doesn&apos;t exists</source>
        <translation type="obsolete">Папка не существует</translation>
    </message>
    <message>
        <source>Folder %1 doesn&apos;t exists
Do you wish to create this folder?</source>
        <translation type="obsolete">Папка %1 не существует
Вы хотите создать эту папку?</translation>
    </message>
</context>
<context>
    <name>U2::ProjectViewImpl</name>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="75"/>
        <source>projectview_sname</source>
        <translation>Навигатор проектов</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="75"/>
        <source>projectview_sdesc</source>
        <translation>Навигатор проектов обеспечивает основные операции над проектами.</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="127"/>
        <source>save_selected_modified_docs_action</source>
        <translation>Сохранить выбранные документы</translation>
    </message>
    <message>
        <source>creating_new_document_lm %1</source>
        <translation type="obsolete">Новый документ добавлен в проект: %1</translation>
    </message>
    <message>
        <source>adding_existing_document %1</source>
        <translation type="obsolete">Существующий документ добавлен в проект: %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="426"/>
        <source>active_views_menu</source>
        <translation>Открытые окна</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="479"/>
        <source>activate_view_action_%1</source>
        <translation>Переключиться на %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="489"/>
        <source>open_view_action_%1</source>
        <translation>Открыть как %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="498"/>
        <source>open_state_%1_%2</source>
        <translation>Открыть закладку %1 (%2)</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="519"/>
        <source>open_view_submenu_%1</source>
        <translation>Открыть (%1)</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="546"/>
        <source>add_to_view_action_%1</source>
        <translation>Добавить в %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="589"/>
        <source>open_view_menu</source>
        <translation>Открыть окно</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="590"/>
        <source>add_to_view_menu</source>
        <translation>Добавить в окно</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="654"/>
        <source>error_adding_object_to_view_title</source>
        <translation>Операция не удалась</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="325"/>
        <source>unnamed_project_name</source>
        <translation>-</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="119"/>
        <source>Open as...</source>
        <translation>Открыть как...</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="130"/>
        <source>Relocate..</source>
        <translation>Переместить...</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="134"/>
        <source>Save a copy..</source>
        <translation>Сохранить копию ...</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="298"/>
        <source>Creating new document %1</source>
        <translation>Создание нового документа: %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="360"/>
        <source>Adding existing document %1</source>
        <translation>Добавление существующего документа: %1</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="381"/>
        <source>Add and load document</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="733"/>
        <source>Select new file location</source>
        <translation>Выбор нового адреса</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="758"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="758"/>
        <source>Document with the same URL is added to the project. 
 Remove it from the project first.</source>
        <translation>Документ с таким адресом уже добавлен в проект. Удалите его из проекта или укажите другой адрес.</translation>
    </message>
</context>
<context>
    <name>U2::ProjectViewWidget</name>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="57"/>
        <source>Project</source>
        <translation>Проект</translation>
    </message>
    <message>
        <location filename="../src/project_view/ProjectViewImpl.cpp" line="50"/>
        <source>Group mode</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>U2::RegisterProjectServiceTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="396"/>
        <source>Register project</source>
        <translation>Регистрация проекта</translation>
    </message>
</context>
<context>
    <name>U2::ResourceSettingsGUIPageController</name>
    <message>
        <location filename="../src/app_settings/resource_settings/ResourceSettingsGUIController.cpp" line="12"/>
        <source>Resources</source>
        <translation>Ресурсы</translation>
    </message>
</context>
<context>
    <name>U2::SaveOnlyProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="298"/>
        <source>Save project</source>
        <translation>Сохранение проекта</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="344"/>
        <source>Saving project %1</source>
        <translation>Сохранение проекта: %1 </translation>
    </message>
</context>
<context>
    <name>U2::SaveProjectTask</name>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="251"/>
        <source>UGENE</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="251"/>
        <source>Save current project?</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="284"/>
        <source>Save documents, remove phantom docs, save  project</source>
        <translation>Сохранение документов, удаление виртуальных документов, сохранение проекта</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="232"/>
        <source>save_project_task_name</source>
        <translation>Сохранение проекта</translation>
    </message>
    <message>
        <source>question</source>
        <translation type="obsolete">Подтверждение</translation>
    </message>
    <message>
        <source>save_project_file_question</source>
        <translation type="obsolete">Сохранить файл проекта?</translation>
    </message>
    <message>
        <location filename="../src/project_support/ProjectTasksGui.cpp" line="255"/>
        <source>My project</source>
        <translation>Мой проект</translation>
    </message>
    <message>
        <source>Saving project %1</source>
        <translation type="obsolete">Сохранение проекта: %1 </translation>
    </message>
</context>
<context>
    <name>U2::ScriptManagerDialog</name>
    <message>
        <source>script_registry_title</source>
        <translation type="obsolete">Реестр скриптов</translation>
    </message>
</context>
<context>
    <name>U2::ScriptManagerView</name>
    <message>
        <source>script_manager</source>
        <translation type="obsolete">Менеджер скриптов</translation>
    </message>
</context>
<context>
    <name>U2::ScriptManagerWidgetImpl</name>
    <message>
        <source>Qt scripts</source>
        <translation type="obsolete">Скрипты Qt</translation>
    </message>
    <message>
        <source>All files</source>
        <translation type="obsolete">Все файлы</translation>
    </message>
    <message>
        <source>add_scripts_caption</source>
        <translation type="obsolete">Зарегистрировать скрипт</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation type="obsolete">Внимание</translation>
    </message>
    <message>
        <source>script_%1_already_registered</source>
        <translation type="obsolete">Скрипт уже зарегистрирован: %1</translation>
    </message>
    <message>
        <source>delete_question</source>
        <translation type="obsolete">Подтверждение удаления скрипта</translation>
    </message>
    <message>
        <source>really_want_delete?</source>
        <translation type="obsolete">Скрипт будет удалён из списка. Продолжить?</translation>
    </message>
</context>
<context>
    <name>U2::Shtirlitz</name>
    <message>
        <source>Shirlitz awakes</source>
        <translation type="obsolete">Инициализация </translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="84"/>
        <source>Statistical reports</source>
        <translation>Отчеты о статистике использования</translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="90"/>
        <source>Shtirlitz is sending the first-time report</source>
        <translation>Отправляется отчет о системе</translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="107"/>
        <source>%1 days passed passed since previous Shtirlitz&apos;s report. Shtirlitz is sending the new one.</source>
        <translation>%1 дней прошло со времени отправки последнего отчета. Отправляется новый отчет.</translation>
    </message>
</context>
<context>
    <name>U2::ShtirlitzTask</name>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="243"/>
        <source>Connecting to remote server</source>
        <translation>Соединение с удаленным сервером</translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="263"/>
        <source>Cannot resolve destination path for statistical reports</source>
        <translation>Невозможно определить адрес сервера статистики</translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="267"/>
        <source>Network error while resolving destination URL: </source>
        <translation>Ошибка сети при определении адреса сервера статистики</translation>
    </message>
    <message>
        <location filename="../src/shtirlitz/Shtirlitz.cpp" line="280"/>
        <source>Network error while sending report: </source>
        <translation>Ошибка сети при отправке отчета</translation>
    </message>
</context>
<context>
    <name>U2::ShutdownTask</name>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="16"/>
        <source>shutdown_task_name</source>
        <translation>Завершение программы</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="137"/>
        <source>Starting shutdown process...</source>
        <translation>Завершение программы...</translation>
    </message>
    <message>
        <source>Shutdown was canceled</source>
        <translation type="obsolete">Завершение программы было отменено</translation>
    </message>
    <message>
        <source>Shutdown failed, error: %1</source>
        <translation type="obsolete">Не удалось завершить программу: %1</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="68"/>
        <source>Close windows</source>
        <translation>Закрытие окон</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="105"/>
        <source>Cancel active tasks</source>
        <translation>Отмена активных задач</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="156"/>
        <source>Shutdown confirmation</source>
        <translation>Подтверждение</translation>
    </message>
    <message>
        <location filename="../src/main_window/ShutdownTask.cpp" line="157"/>
        <source>There are active tasks. Stop them now?</source>
        <translation>Имеются запущенные задачи. Остановить их?</translation>
    </message>
</context>
<context>
    <name>U2::TBoard</name>
    <message>
        <location filename="../src/main_window/AboutDialogController.cpp" line="367"/>
        <source>Pause</source>
        <translation>Пауза</translation>
    </message>
</context>
<context>
    <name>U2::TVReportWindow</name>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="412"/>
        <source>report_for_%1</source>
        <translation>Отчёт выполнения задачи  - %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="423"/>
        <source>Failed</source>
        <translation>Провалилась</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="423"/>
        <source>Canceled</source>
        <translation>Отменена</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="423"/>
        <source>Finished</source>
        <translation>Завершена</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="424"/>
        <source>status</source>
        <translation>состояние</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="426"/>
        <source>error:</source>
        <translation>ошибка:</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="432"/>
        <source>time</source>
        <translation>время выполнения</translation>
    </message>
</context>
<context>
    <name>U2::TaskStatusBar</name>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="88"/>
        <source>%1Report for task: &apos;%2&apos;</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="91"/>
        <source>%1&apos;%2&apos; task failed: %3</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="121"/>
        <source>num_reports_%1</source>
        <translation>Отчётов: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="126"/>
        <source>no_active_tasks</source>
        <translation>Нет задач</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="135"/>
        <source>running_task_%1</source>
        <translation>Активная задача: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="144"/>
        <source>_info_%1</source>
        <translation>: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="149"/>
        <source>num_tasks_%1_num_reports_%2</source>
        <translation>Задач: %1 Отчётов: %2</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="151"/>
        <source>num_tasks_%1</source>
        <translation>Задач: %1</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="224"/>
        <source>%1 notification(s)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskStatusBar.cpp" line="137"/>
        <source>canceling...</source>
        <translation>отменяется...</translation>
    </message>
</context>
<context>
    <name>U2::TaskViewDockWidget</name>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="28"/>
        <source>Tasks</source>
        <translation>Задачи</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="61"/>
        <source>cancel_task_action</source>
        <translation>Отменить задачу</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="65"/>
        <source>view_task_report_action</source>
        <translation>Открыть отчёт</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="69"/>
        <source>remove_task_report_action</source>
        <translation>Удалить отчёт</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="99"/>
        <source>task_name_column</source>
        <translation>Имя</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="100"/>
        <source>task_current_desc_column</source>
        <translation>Описание</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="101"/>
        <source>task_progress_column</source>
        <translation>Прогресс</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="102"/>
        <source>task_actions_column</source>
        <translation>Операции</translation>
    </message>
    <message>
        <source>New report available from task: %1</source>
        <translation type="obsolete">Доступен отчёт о выполнении задачи &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="274"/>
        <source>Activating task report: %1</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="494"/>
        <source>finished</source>
        <translation>Завершена</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="476"/>
        <source>Canceling...</source>
        <translation>Отмена задачи...</translation>
    </message>
    <message>
        <location filename="../src/task_view/TaskViewController.cpp" line="474"/>
        <source>Canceled</source>
        <translation>Отменена</translation>
    </message>
</context>
<context>
    <name>U2::UserApplicationsSettingsPageController</name>
    <message>
        <source>user_apps</source>
        <translation type="obsolete">Прочие настройки</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="17"/>
        <source>General</source>
        <translation type="unfinished">Основные настройки</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="23"/>
        <source>File with translations is not found: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="37"/>
        <source>Illegal entry in translations file: %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>transmap_file_not_found_%1</source>
        <translation type="obsolete">Не найден список переводов: %1</translation>
    </message>
    <message>
        <source>illegal_entry_%1</source>
        <translation type="obsolete">Нераспознан элемент в списке переводов: %1</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="19"/>
        <source>Autodetection</source>
        <translation>Автоопределение</translation>
    </message>
</context>
<context>
    <name>U2::UserApplicationsSettingsPageWidget</name>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="114"/>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="172"/>
        <source>Custom translation [%1]</source>
        <translation>Другой перевод [%1]</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="136"/>
        <source>file_not_exists</source>
        <translation>Файл не существует</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="153"/>
        <source>select_wb_file_title</source>
        <translation>Выбрать исполняемый файл браузера</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="160"/>
        <source>select_trans_file_title</source>
        <translation>Выбрать файл перевода</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="181"/>
        <location filename="../src/app_settings/user_apps_settings/UserApplicationsSettingsGUIController.cpp" line="193"/>
        <source>Choose Directory</source>
        <translation>Выбор директории</translation>
    </message>
</context>
<context>
    <name>UserApplicationsSettingsWidget</name>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="26"/>
        <source>LangBoxTitle</source>
        <translation>Язык интерфейса (изменение после перезапуска)</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="35"/>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="113"/>
        <source>...</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="69"/>
        <source>web_browser</source>
        <translation>Предпочитаемый Интернет-браузер </translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="86"/>
        <source>use_default_web_browser</source>
        <translation>Стандартный браузер ОС</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="96"/>
        <source>web_browser_path</source>
        <translation>Указанное приложение</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="125"/>
        <source>Project</source>
        <translation>Проект</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="131"/>
        <source>auto_open_project_at_startup</source>
        <translation>Открывать последний проект при старте</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="141"/>
        <source>Path to downloaded data:</source>
        <translation>Папка для загрузок:</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="152"/>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="191"/>
        <source>Browse...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="164"/>
        <source>Statistical reports</source>
        <translation>Отчеты о статистике использования</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="170"/>
        <source>Enable statistical reports collecting</source>
        <translation>Разрешить сбор отчетов</translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="180"/>
        <source>Path for temporary files</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/app_settings/user_apps_settings/ui/UserApplicationsSettingsWidget.ui" line="45"/>
        <source>Appearance</source>
        <translation>Стиль</translation>
    </message>
</context>
</TS>
